@@ -43,14 +43,6 @@ typedef struct {
 
 void cal_obj_instance_list_free (GList *list);
 
-/* Used for multiple UID queries */
-typedef enum {
-	CALOBJ_TYPE_EVENT   = 1 << 0,
-	CALOBJ_TYPE_TODO    = 1 << 1,
-	CALOBJ_TYPE_JOURNAL = 1 << 2,
-	CALOBJ_TYPE_ANY     = 0x07
-} CalObjType;
-
 /* Used for modifying objects */
 typedef enum {
 	CALOBJ_MOD_THIS          = 1 << 0,
@@ -67,6 +59,11 @@ typedef enum {
 	CAL_MODE_ANY     = 0x07
 } CalMode;
 
+#define cal_mode_to_corba(mode) \
+	(mode == CAL_MODE_LOCAL   ? GNOME_Evolution_Calendar_MODE_LOCAL  : \
+	 mode == CAL_MODE_REMOTE  ? GNOME_Evolution_Calendar_MODE_REMOTE : \
+	 GNOME_Evolution_Calendar_MODE_ANY)
+
 void cal_obj_uid_list_free (GList *list);
 
 icalcomponent *e_cal_util_new_top_level (void);
